@@ -2,9 +2,9 @@ from abc import abstractmethod
 from functools import cached_property
 from typing import Callable, Iterable
 
-from platonic.queue.message import Message
-from platonic.queue.types import ValueType, InternalType
 from platonic.queue.base import BaseQueue
+from platonic.queue.message import Message
+from platonic.queue.types import InternalType, ValueType
 
 
 class OutputQueue(BaseQueue[ValueType]):
